@@ -15,8 +15,14 @@ class StyleConverter(object):
         if style.is_bold():
             options.append("bold")
 
+        if style.is_italic():
+            options.append("italic")
+
+        if style.is_dark():
+            options.append("dark")
+
         if style.is_underlined():
-            options.append("underscore")
+            options.append("underline")
 
         if style.is_blinking():
             options.append("blink")
